==> blancoMessage-0.1.9-src.zip: blancoMessage/blanco.ruby/main/blanco/sample/message/SampleMessage.rb <==
#
# ̃\[XR[h blanco FrameworkɂĎĂ܂B
#

#
# bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
#
class SampleMessage

    #
    # [bZ[W̃TvB̂PB]
    #
    # No.1:
    #
    MESSAGE001 = 'bZ[W̃TvB̂PB'

    #
    # [bZ[Wu[{0}]u܂B]
    #
    # No.2:
    #
    MESSAGE002 = 'bZ[Wu[{0}]u܂B'

    #
    # [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
    #
    # No.3:
    #
    MESSAGE003 = 'bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B'

    #
    # [AbZ[Wu{0}{1}̗łB]
    #
    # No.4:
    #
    MESSAGE004 = 'AbZ[Wu{0}{1}̗łB'

    #
    # [{0}擪u񂪂B]
    #
    # No.5:
    #
    MESSAGE005 = '{0}擪u񂪂B'

    #
    # [Ōオu̗B{0}]
    #
    # No.6:
    #
    MESSAGE006 = 'Ōオu̗B{0}'

    #
    # [xu{0}{1}{0}{1}{2}{1}{0}]
    #
    # No.7:
    #
    MESSAGE007 = 'xu{0}{1}{0}{1}{2}{1}{0}'

    #
    # [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
    #
    # No.8:
    #
    MESSAGE008 = '̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B'

    #
    # [ԍԂƒu{1}B0IWłB]
    #
    # No.9:
    #
    MESSAGE009 = 'ԍԂƒu{1}B0IWłB'

    #
    # [GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]
    #
    # No.10:
    #
    MESSAGE010 = 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'

    #
    # [~]
    #
    # No.11:
    #
    MESSAGE011 = '~'

    #
    # [s[\n]̎B]
    #
    # No.12:
    #
    MESSAGE012 = 's[\n]̎B'

    #
    # bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B
    #
    # No.1:
    # [bZ[W̃TvB̂PB]
    #
    # return bZ[WB
    #
    def getMessage001()
        return 'bZ[W̃TvB̂PB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B
    #
    # No.2:
    # [bZ[Wu[{0}]u܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage002(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage002]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'bZ[Wu[' + arg0 + ']u܂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B
    #
    # No.3:
    # [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMessage003(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage003]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage003]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'bZ[Wu[' + arg0 + ']ɉAЂƂ[' + arg1 + ']u܂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B
    #
    # No.4:
    # [AbZ[Wu{0}{1}̗łB]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMessage004(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage004]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage004]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'AbZ[Wu' + arg0 + arg1 + '̗łB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B
    #
    # No.5:
    # [{0}擪u񂪂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage005(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage005]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return arg0 + '擪u񂪂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B
    #
    # No.6:
    # [Ōオu̗B{0}]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage006(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage006]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'Ōオu̗B' + arg0
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B
    #
    # No.7:
    # [xu{0}{1}{0}{1}{2}{1}{0}]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # return bZ[WB
    #
    def getMessage007(arg0, arg1, arg2)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'xu' + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B
    #
    # No.8:
    # [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # param arg3 u{3}̒lB
    # param arg4 u{4}̒lB
    # param arg5 u{5}̒lB
    # param arg6 u{6}̒lB
    # param arg7 u{7}̒lB
    # param arg8 u{8}̒lB
    # param arg9 u{9}̒lB
    # param arg10 u{10}̒lB
    # param arg11 u{11}̒lB
    # return bZ[WB
    #
    def getMessage008(arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg3.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg3]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg4.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg4]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg5.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg5]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg6.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg6]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg7.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg7]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg8.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg8]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg9.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg9]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg10.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg10]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg11.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg11]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '̒uB' + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + '12B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B
    #
    # No.9:
    # [ԍԂƒu{1}B0IWłB]
    #
    # return bZ[WB
    #
    def getMessage009()
        return 'ԍԂƒu{1}B0IWłB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B
    #
    # No.10:
    # [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]
    #
    # return bZ[WB
    #
    def getMessage010()
        return 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B
    #
    # No.11:
    # [~]
    #
    # return bZ[WB
    #
    def getMessage011()
        return '~'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B
    #
    # No.12:
    # [s[\n]̎B]
    #
    # return bZ[WB
    #
    def getMessage012()
        return 's[' + "\n" + ']̎B'
    end
end

==> blancoMessage-0.5.6-src.zip: blancoMessage/blanco.ruby/main/blanco/sample/message/SampleMessage.rb <==
#
# ̃\[XR[h blanco FrameworkɂĎĂ܂B
#

#
# bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
#
class SampleMessage

    #
    # [bZ[W̃TvB̂PB]
    #
    # No.1:
    #
    MESSAGE001 = 'bZ[W̃TvB̂PB'

    #
    # [bZ[Wu[{0}]u܂B]
    #
    # No.2:
    #
    MESSAGE002 = 'bZ[Wu[{0}]u܂B'

    #
    # [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
    #
    # No.3:
    #
    MESSAGE003 = 'bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B'

    #
    # [AbZ[Wu{0}{1}̗łB]
    #
    # No.4:
    #
    MESSAGE004 = 'AbZ[Wu{0}{1}̗łB'

    #
    # [{0}擪u񂪂B]
    #
    # No.5:
    #
    MESSAGE005 = '{0}擪u񂪂B'

    #
    # [Ōオu̗B{0}]
    #
    # No.6:
    #
    MESSAGE006 = 'Ōオu̗B{0}'

    #
    # [xu{0}{1}{0}{1}{2}{1}{0}]
    #
    # No.7:
    #
    MESSAGE007 = 'xu{0}{1}{0}{1}{2}{1}{0}'

    #
    # [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
    #
    # No.8:
    #
    MESSAGE008 = '̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B'

    #
    # [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
    #
    # No.9:
    #
    MESSAGE009 = '{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB'

    #
    # [GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]
    #
    # No.10:
    #
    MESSAGE010 = 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'

    #
    # [~]
    #
    # No.11:
    #
    MESSAGE011 = '~'

    #
    # [s[\n]̎B]
    #
    # No.12:
    #
    MESSAGE012 = 's[\n]̎B'

    #
    # bZ[W`ID[Sample]AL[[MESSAGE001]̕擾܂B
    #
    # No.1:
    # [bZ[W̃TvB̂PB]
    #
    # return bZ[WB
    #
    def getMessage001()
        return 'bZ[W̃TvB̂PB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE002]̕擾܂B
    #
    # No.2:
    # [bZ[Wu[{0}]u܂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage002(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage002]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'bZ[Wu[' + arg0 + ']u܂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE003]̕擾܂B
    #
    # No.3:
    # [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMessage003(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage003]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage003]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'bZ[Wu[' + arg0 + ']ɉAЂƂ[' + arg1 + ']u܂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE004]̕擾܂B
    #
    # No.4:
    # [AbZ[Wu{0}{1}̗łB]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMessage004(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage004]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage004]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'AbZ[Wu' + arg0 + arg1 + '̗łB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE005]̕擾܂B
    #
    # No.5:
    # [{0}擪u񂪂B]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage005(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage005]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return arg0 + '擪u񂪂B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE006]̕擾܂B
    #
    # No.6:
    # [Ōオu̗B{0}]
    #
    # param arg0 u{0}̒lB
    # return bZ[WB
    #
    def getMessage006(arg0)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage006]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'Ōオu̗B' + arg0
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE007]̕擾܂B
    #
    # No.7:
    # [xu{0}{1}{0}{1}{2}{1}{0}]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # return bZ[WB
    #
    def getMessage007(arg0, arg1, arg2)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMessage007]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return 'xu' + arg0 + arg1 + arg0 + arg1 + arg2 + arg1 + arg0
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE008]̕擾܂B
    #
    # No.8:
    # [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # param arg2 u{2}̒lB
    # param arg3 u{3}̒lB
    # param arg4 u{4}̒lB
    # param arg5 u{5}̒lB
    # param arg6 u{6}̒lB
    # param arg7 u{7}̒lB
    # param arg8 u{8}̒lB
    # param arg9 u{9}̒lB
    # param arg10 u{10}̒lB
    # param arg11 u{11}̒lB
    # return bZ[WB
    #
    def getMessage008(arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg2.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg2]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg3.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg3]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg4.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg4]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg5.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg5]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg6.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg6]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg7.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg7]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg8.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg8]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg9.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg9]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg10.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg10]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg11.nil?
            raise ArgumentError, "\bh[getMessage008]̃p[^[arg11]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return '̒uB' + arg11 + arg10 + arg9 + arg8 + arg7 + arg6 + arg5 + arg4 + arg3 + arg2 + arg1 + arg0 + '12B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE009]̕擾܂B
    #
    # No.9:
    # [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
    #
    # param arg0 u{0}̒lB
    # param arg1 u{1}̒lB
    # return bZ[WB
    #
    def getMessage009(arg0, arg1)
        if arg0.nil?
            raise ArgumentError, "\bh[getMessage009]̃p[^[arg0]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end
        if arg1.nil?
            raise ArgumentError, "\bh[getMessage009]̃p[^[arg1]nil^܂BÃp[^nil^邱Ƃ͂ł܂"
        end

        return arg0 + 'ԍԂƒu͕sƂĔf܂B' + arg1 + 'B̒`0IWłB'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE010]̕擾܂B
    #
    # No.10:
    # [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]
    #
    # return bZ[WB
    #
    def getMessage010()
        return 'GXP[v̊mFB_uNI[e[V"AVONI[e[V\'AG}[N\\B'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE011]̕擾܂B
    #
    # No.11:
    # [~]
    #
    # return bZ[WB
    #
    def getMessage011()
        return '~'
    end

    #
    # bZ[W`ID[Sample]AL[[MESSAGE012]̕擾܂B
    #
    # No.12:
    # [s[\n]̎B]
    #
    # return bZ[WB
    #
    def getMessage012()
        return 's[' + "\n" + ']̎B'
    end
end
